componenttools.copy_components_and_covered_spanners
===================================================

.. autofunction:: abjad.tools.componenttools.copy_components_and_covered_spanners.copy_components_and_covered_spanners
